@@ -4,6 +4,7 @@ import re
 import inspect
 import os
 import shutil
+from pathlib import Path
 
 from elephas import spark_model, ml_model
 from elephas.parameter import client, server
@@ -22,6 +23,7 @@ EXCLUDE = {
     'SocketServer'
 }
 
+PWD = Path(__file__).parent
 
 PAGES = [
     {
@@ -53,12 +55,6 @@ PAGES = [
             ml_model.load_ml_estimator
         ],
     },
-    {
-        'page': 'models/hyper-param-model.md',
-        'classes': [
-            hyperparam.HyperParamModel
-        ]
-    },
     {
         'page': 'parameter/client.md',
         'classes': [
@@ -95,38 +91,23 @@ PAGES = [
     },
 ]
 
-ROOT = 'http://maxpumperla.com/elephas'
+ROOT = 'http://danielenricocahall.com/elephas'
 
 
 def get_function_signature(function, method=True):
     wrapped = getattr(function, '_original_function', None)
     if wrapped is None:
-        signature = inspect.getargspec(function)
+        signature = inspect.signature(function)
     else:
-        signature = inspect.getargspec(wrapped)
-    defaults = signature.defaults
+        signature = inspect.signature(wrapped)
+    parameters = [str(p[1]) for p in signature.parameters.items()]
     if method:
-        args = signature.args[1:]
-    else:
-        args = signature.args
-    if defaults:
-        kwargs = zip(args[-len(defaults):], defaults)
-        args = args[:-len(defaults)]
-    else:
-        kwargs = []
+        parameters = parameters[1:]
     st = '%s.%s(' % (clean_module_name(function.__module__), function.__name__)
 
-    for a in args:
-        st += str(a) + ', '
-    for a, v in kwargs:
-        if isinstance(v, str):
-            v = '\'' + v + '\''
-        st += str(a) + '=' + str(v) + ', '
-    if kwargs or args:
-        signature = st[:-2] + ')'
-    else:
-        signature = st + ')'
-    return signature
+    for p in parameters:
+        st += str(p) + ', '
+    return st[:-2] + ')'
 
 
 def get_class_signature(cls):
@@ -160,7 +141,7 @@ def class_to_source_link(cls):
     path = module_name.replace('.', '/')
     path += '.py'
     line = inspect.getsourcelines(cls)[-1]
-    link = ('https://github.com/maxpumperla/'
+    link = ('https://github.com/danielenricocahall/'
             'elephas/blob/master/' + path + '#L' + str(line))
     return '[[source]](' + link + ')'
 
@@ -295,18 +276,19 @@ def process_docstring(docstring):
             '$CODE_BLOCK_%d' % i, code_block)
     return docstring
 
-print('Cleaning up existing sources directory.')
-if os.path.exists('sources'):
-    shutil.rmtree('sources')
+
+if os.path.exists(PWD/'sources'):
+    print('Cleaning up existing sources directory.')
+    shutil.rmtree(PWD/'sources')
 
 print('Populating sources directory with templates.')
-for subdir, dirs, fnames in os.walk('templates'):
+for subdir, dirs, fnames in os.walk(PWD/'templates'):
     for fname in fnames:
-        new_subdir = subdir.replace('templates', 'sources')
-        if not os.path.exists(new_subdir):
-            os.makedirs(new_subdir)
+        new_subdir = subdir.replace(str(PWD/'templates'), str(PWD/'sources'))
+        if not os.path.exists(PWD/new_subdir):
+            os.makedirs(PWD/new_subdir)
         if fname[-3:] == '.md':
-            fpath = os.path.join(subdir, fname)
+            fpath = str(PWD/os.path.join(subdir, fname))
             new_fpath = fpath.replace('templates', 'sources')
             shutil.copy(fpath, new_fpath)
 
@@ -362,10 +344,10 @@ def read_page_data(page_data, type):
 
 
 if __name__ == '__main__':
-    readme = read_file('../README.md')
-    index = read_file('templates/index.md')
+    readme = read_file(PWD.parent/'README.md')
+    index = read_file(PWD/'templates/index.md')
     index = index.replace('{{autogenerated}}', readme[readme.find('##'):])
-    with open('sources/index.md', 'w') as f:
+    with open(PWD/'sources/index.md', 'w') as f:
         f.write(index)
 
     print('Generating Elephas docs')
@@ -416,7 +398,7 @@ if __name__ == '__main__':
         # Either insert content into existing page,
         # or create page otherwise
         page_name = page_data['page']
-        path = os.path.join('sources', page_name)
+        path = os.path.join(PWD/'sources', page_name)
         if os.path.exists(path):
             template = read_file(path)
             assert '{{autogenerated}}' in template, ('Template found for ' + path +
@@ -427,7 +409,7 @@ if __name__ == '__main__':
         else:
             print('...creating new page with autogenerated content:', path)
         subdir = os.path.dirname(path)
-        if not os.path.exists(subdir):
-            os.makedirs(subdir)
+        if not os.path.exists(PWD/subdir):
+            os.makedirs(PWD/subdir)
         with open(path, 'w') as f:
             f.write(mkdown)
